import { __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, EventEmitter, Input, Output, ViewChild, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { FullCalendarModule } from '@fullcalendar/angular';
import timeGridPlugin from '@fullcalendar/timegrid';
import dayGridPlugin from '@fullcalendar/daygrid';
import interactionPlugin from '@fullcalendar/interaction';
import { BrowserModule } from '@angular/platform-browser';

let EqpCalendarService = class EqpCalendarService {
    constructor() {
    }
};
EqpCalendarService.ɵprov = ɵɵdefineInjectable({ factory: function EqpCalendarService_Factory() { return new EqpCalendarService(); }, token: EqpCalendarService, providedIn: "root" });
EqpCalendarService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], EqpCalendarService);

let EqpCalendarComponent = class EqpCalendarComponent {
    constructor() {
        this.eventList = new Array();
        this.customStyle = { 'text-transform': 'capitalize' };
        this.initialView = "dayGridMonth";
        this.firstDay = 1;
        this.contentHeight = null;
        this.locale = "it-IT";
        this.monthButtonText = "Mese";
        this.weekButtonText = "Settimana";
        this.dayButtonText = "Giorno";
        this.todayButtonText = "Oggi";
        this.listButtonText = "Lista";
        this.headerToolbarStart = 'title';
        this.headerToolbarCenter = "dayGridMonth,timeGridWeek,timeGridDay";
        this.headerToolbarEnd = "today prev,next";
        this.allDayText = "Tutto il giorno";
        this.eventOrder = null;
        this.onViewDateChange = new EventEmitter();
        this.onDateClick = new EventEmitter();
        this.onEventClick = new EventEmitter();
        this.calendarOptions = {};
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        if (this.calendarComponent)
            this.calendarApi = this.calendarComponent.getApi();
        this.configureCalendar();
        setTimeout(() => {
            this.calendarApi.updateSize();
        }, 190);
    }
    ngOnChanges(changes) {
        if (changes['eventList'] != undefined && changes['eventList'].firstChange == false && JSON.stringify(changes['eventList'].currentValue) != JSON.stringify(changes['eventList'].previousValue)) {
            this.calendarOptions.events = this.eventList;
            this.calendarApi.refetchEvents();
        }
    }
    configureCalendar() {
        this.calendarOptions = {
            initialView: this.initialView,
            firstDay: this.firstDay,
            contentHeight: this.contentHeight,
            locale: this.locale,
            customButtons: {
                today: {
                    text: this.todayButtonText,
                    click: (event) => {
                        this.calendarApi.today();
                        this.viewDateChange();
                    }
                },
                prev: {
                    click: (event) => {
                        this.calendarApi.prev();
                        this.viewDateChange();
                    }
                },
                next: {
                    click: (event) => {
                        this.calendarApi.next();
                        this.viewDateChange();
                    }
                },
                dayGridMonth: {
                    text: this.monthButtonText,
                    click: (event) => {
                        this.calendarApi.changeView("dayGridMonth");
                        this.viewDateChange();
                    }
                },
                timeGridWeek: {
                    text: this.weekButtonText,
                    click: (event) => {
                        this.calendarApi.changeView("timeGridWeek");
                        this.viewDateChange();
                    }
                },
                timeGridDay: {
                    text: this.dayButtonText,
                    click: (event) => {
                        this.calendarApi.changeView("timeGridDay");
                        this.viewDateChange();
                    }
                }
            },
            headerToolbar: {
                start: this.headerToolbarStart,
                center: this.headerToolbarCenter,
                end: this.headerToolbarEnd,
            },
            buttonText: {
                month: this.monthButtonText,
                week: this.weekButtonText,
                day: this.dayButtonText,
                today: this.todayButtonText,
                list: this.listButtonText
            },
            allDayText: this.allDayText,
            eventClick: (event) => { this.eventClick(event); },
            dateClick: this.dateClick.bind(this),
            eventOrder: (eventA, eventB) => { return ((eventA && eventB && this.eventOrder) ? this.eventOrder(eventA, eventB) : 0); }
        };
        this.calendarOptions.events = this.eventList;
        this.calendarApi.refetchEvents();
    }
    viewDateChange() {
        let newRange = {
            dateStart: this.calendarApi.view.currentStart,
            dateEnd: this.calendarApi.view.currentEnd,
            viewMode: this.calendarApi.view.type
        };
        this.onViewDateChange.emit(newRange);
    }
    dateClick(event) {
        this.onDateClick.emit(event.date);
    }
    eventClick(event) {
        this.onEventClick.emit(event.event);
    }
};
__decorate([
    Input("EventList")
], EqpCalendarComponent.prototype, "eventList", void 0);
__decorate([
    Input("CustomStyle")
], EqpCalendarComponent.prototype, "customStyle", void 0);
__decorate([
    Input("InitialView")
], EqpCalendarComponent.prototype, "initialView", void 0);
__decorate([
    Input("FirstDay")
], EqpCalendarComponent.prototype, "firstDay", void 0);
__decorate([
    Input("ContentHeight")
], EqpCalendarComponent.prototype, "contentHeight", void 0);
__decorate([
    Input("Locale")
], EqpCalendarComponent.prototype, "locale", void 0);
__decorate([
    Input("MonthButtonText")
], EqpCalendarComponent.prototype, "monthButtonText", void 0);
__decorate([
    Input("WeekButtonText")
], EqpCalendarComponent.prototype, "weekButtonText", void 0);
__decorate([
    Input("DayButtonText")
], EqpCalendarComponent.prototype, "dayButtonText", void 0);
__decorate([
    Input("TodayButtonText")
], EqpCalendarComponent.prototype, "todayButtonText", void 0);
__decorate([
    Input("ListButtonText")
], EqpCalendarComponent.prototype, "listButtonText", void 0);
__decorate([
    Input("HeaderToolbarStart")
], EqpCalendarComponent.prototype, "headerToolbarStart", void 0);
__decorate([
    Input("HeaderToolbarCenter")
], EqpCalendarComponent.prototype, "headerToolbarCenter", void 0);
__decorate([
    Input("HeaderToolbarEnd")
], EqpCalendarComponent.prototype, "headerToolbarEnd", void 0);
__decorate([
    Input("AllDayText")
], EqpCalendarComponent.prototype, "allDayText", void 0);
__decorate([
    Input("EventOrder")
], EqpCalendarComponent.prototype, "eventOrder", void 0);
__decorate([
    Output("OnViewDateChange")
], EqpCalendarComponent.prototype, "onViewDateChange", void 0);
__decorate([
    Output("OnDateClick")
], EqpCalendarComponent.prototype, "onDateClick", void 0);
__decorate([
    Output("OnEventClick")
], EqpCalendarComponent.prototype, "onEventClick", void 0);
__decorate([
    ViewChild('calendar')
], EqpCalendarComponent.prototype, "calendarComponent", void 0);
EqpCalendarComponent = __decorate([
    Component({
        selector: 'eqp-calendar',
        template: "<full-calendar [options]=\"calendarOptions\" #calendar [ngStyle]=\"customStyle\"></full-calendar>",
        styles: [""]
    })
], EqpCalendarComponent);

FullCalendarModule.registerPlugins([
    dayGridPlugin,
    timeGridPlugin,
    interactionPlugin
]);
let EqpCalendarModule = class EqpCalendarModule {
};
EqpCalendarModule = __decorate([
    NgModule({
        declarations: [EqpCalendarComponent],
        imports: [
            CommonModule,
            BrowserModule,
            FormsModule,
            ReactiveFormsModule,
            FullCalendarModule
        ],
        exports: [EqpCalendarComponent]
    })
], EqpCalendarModule);

class ViewDateChangeEvent {
}

/*
 * Public API Surface of eqp-calendar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EqpCalendarComponent, EqpCalendarModule, EqpCalendarService, ViewDateChangeEvent };
//# sourceMappingURL=eqproject-eqp-calendar.js.map
