import { __decorate } from 'tslib';
import { ɵɵdefineInjectable, Injectable, EventEmitter, Input, Output, ViewChild, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { FullCalendarModule } from '@fullcalendar/angular';
import timeGridPlugin from '@fullcalendar/timegrid';
import dayGridPlugin from '@fullcalendar/daygrid';
import interactionPlugin from '@fullcalendar/interaction';
import { BrowserModule } from '@angular/platform-browser';

var EqpCalendarService = /** @class */ (function () {
    function EqpCalendarService() {
    }
    EqpCalendarService.ɵprov = ɵɵdefineInjectable({ factory: function EqpCalendarService_Factory() { return new EqpCalendarService(); }, token: EqpCalendarService, providedIn: "root" });
    EqpCalendarService = __decorate([
        Injectable({
            providedIn: 'root'
        })
    ], EqpCalendarService);
    return EqpCalendarService;
}());

var EqpCalendarComponent = /** @class */ (function () {
    function EqpCalendarComponent() {
        this.eventList = new Array();
        this.customStyle = { 'text-transform': 'capitalize' };
        this.initialView = "dayGridMonth";
        this.firstDay = 1;
        this.contentHeight = null;
        this.locale = "it-IT";
        this.monthButtonText = "Mese";
        this.weekButtonText = "Settimana";
        this.dayButtonText = "Giorno";
        this.todayButtonText = "Oggi";
        this.listButtonText = "Lista";
        this.headerToolbarStart = 'title';
        this.headerToolbarCenter = "dayGridMonth,timeGridWeek,timeGridDay";
        this.headerToolbarEnd = "today prev,next";
        this.allDayText = "Tutto il giorno";
        this.eventOrder = null;
        this.onViewDateChange = new EventEmitter();
        this.onDateClick = new EventEmitter();
        this.onEventClick = new EventEmitter();
        this.calendarOptions = {};
    }
    EqpCalendarComponent.prototype.ngOnInit = function () {
    };
    EqpCalendarComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        if (this.calendarComponent)
            this.calendarApi = this.calendarComponent.getApi();
        this.configureCalendar();
        setTimeout(function () {
            _this.calendarApi.updateSize();
        }, 190);
    };
    EqpCalendarComponent.prototype.ngOnChanges = function (changes) {
        if (changes['eventList'] != undefined && changes['eventList'].firstChange == false && JSON.stringify(changes['eventList'].currentValue) != JSON.stringify(changes['eventList'].previousValue)) {
            this.calendarOptions.events = this.eventList;
            this.calendarApi.refetchEvents();
        }
    };
    EqpCalendarComponent.prototype.configureCalendar = function () {
        var _this = this;
        this.calendarOptions = {
            initialView: this.initialView,
            firstDay: this.firstDay,
            contentHeight: this.contentHeight,
            locale: this.locale,
            customButtons: {
                today: {
                    text: this.todayButtonText,
                    click: function (event) {
                        _this.calendarApi.today();
                        _this.viewDateChange();
                    }
                },
                prev: {
                    click: function (event) {
                        _this.calendarApi.prev();
                        _this.viewDateChange();
                    }
                },
                next: {
                    click: function (event) {
                        _this.calendarApi.next();
                        _this.viewDateChange();
                    }
                },
                dayGridMonth: {
                    text: this.monthButtonText,
                    click: function (event) {
                        _this.calendarApi.changeView("dayGridMonth");
                        _this.viewDateChange();
                    }
                },
                timeGridWeek: {
                    text: this.weekButtonText,
                    click: function (event) {
                        _this.calendarApi.changeView("timeGridWeek");
                        _this.viewDateChange();
                    }
                },
                timeGridDay: {
                    text: this.dayButtonText,
                    click: function (event) {
                        _this.calendarApi.changeView("timeGridDay");
                        _this.viewDateChange();
                    }
                }
            },
            headerToolbar: {
                start: this.headerToolbarStart,
                center: this.headerToolbarCenter,
                end: this.headerToolbarEnd,
            },
            buttonText: {
                month: this.monthButtonText,
                week: this.weekButtonText,
                day: this.dayButtonText,
                today: this.todayButtonText,
                list: this.listButtonText
            },
            allDayText: this.allDayText,
            eventClick: function (event) { _this.eventClick(event); },
            dateClick: this.dateClick.bind(this),
            eventOrder: function (eventA, eventB) { return ((eventA && eventB && _this.eventOrder) ? _this.eventOrder(eventA, eventB) : 0); }
        };
        this.calendarOptions.events = this.eventList;
        this.calendarApi.refetchEvents();
    };
    EqpCalendarComponent.prototype.viewDateChange = function () {
        var newRange = {
            dateStart: this.calendarApi.view.currentStart,
            dateEnd: this.calendarApi.view.currentEnd,
            viewMode: this.calendarApi.view.type
        };
        this.onViewDateChange.emit(newRange);
    };
    EqpCalendarComponent.prototype.dateClick = function (event) {
        this.onDateClick.emit(event.date);
    };
    EqpCalendarComponent.prototype.eventClick = function (event) {
        this.onEventClick.emit(event.event);
    };
    __decorate([
        Input("EventList")
    ], EqpCalendarComponent.prototype, "eventList", void 0);
    __decorate([
        Input("CustomStyle")
    ], EqpCalendarComponent.prototype, "customStyle", void 0);
    __decorate([
        Input("InitialView")
    ], EqpCalendarComponent.prototype, "initialView", void 0);
    __decorate([
        Input("FirstDay")
    ], EqpCalendarComponent.prototype, "firstDay", void 0);
    __decorate([
        Input("ContentHeight")
    ], EqpCalendarComponent.prototype, "contentHeight", void 0);
    __decorate([
        Input("Locale")
    ], EqpCalendarComponent.prototype, "locale", void 0);
    __decorate([
        Input("MonthButtonText")
    ], EqpCalendarComponent.prototype, "monthButtonText", void 0);
    __decorate([
        Input("WeekButtonText")
    ], EqpCalendarComponent.prototype, "weekButtonText", void 0);
    __decorate([
        Input("DayButtonText")
    ], EqpCalendarComponent.prototype, "dayButtonText", void 0);
    __decorate([
        Input("TodayButtonText")
    ], EqpCalendarComponent.prototype, "todayButtonText", void 0);
    __decorate([
        Input("ListButtonText")
    ], EqpCalendarComponent.prototype, "listButtonText", void 0);
    __decorate([
        Input("HeaderToolbarStart")
    ], EqpCalendarComponent.prototype, "headerToolbarStart", void 0);
    __decorate([
        Input("HeaderToolbarCenter")
    ], EqpCalendarComponent.prototype, "headerToolbarCenter", void 0);
    __decorate([
        Input("HeaderToolbarEnd")
    ], EqpCalendarComponent.prototype, "headerToolbarEnd", void 0);
    __decorate([
        Input("AllDayText")
    ], EqpCalendarComponent.prototype, "allDayText", void 0);
    __decorate([
        Input("EventOrder")
    ], EqpCalendarComponent.prototype, "eventOrder", void 0);
    __decorate([
        Output("OnViewDateChange")
    ], EqpCalendarComponent.prototype, "onViewDateChange", void 0);
    __decorate([
        Output("OnDateClick")
    ], EqpCalendarComponent.prototype, "onDateClick", void 0);
    __decorate([
        Output("OnEventClick")
    ], EqpCalendarComponent.prototype, "onEventClick", void 0);
    __decorate([
        ViewChild('calendar')
    ], EqpCalendarComponent.prototype, "calendarComponent", void 0);
    EqpCalendarComponent = __decorate([
        Component({
            selector: 'eqp-calendar',
            template: "<full-calendar [options]=\"calendarOptions\" #calendar [ngStyle]=\"customStyle\"></full-calendar>",
            styles: [""]
        })
    ], EqpCalendarComponent);
    return EqpCalendarComponent;
}());

FullCalendarModule.registerPlugins([
    dayGridPlugin,
    timeGridPlugin,
    interactionPlugin
]);
var EqpCalendarModule = /** @class */ (function () {
    function EqpCalendarModule() {
    }
    EqpCalendarModule = __decorate([
        NgModule({
            declarations: [EqpCalendarComponent],
            imports: [
                CommonModule,
                BrowserModule,
                FormsModule,
                ReactiveFormsModule,
                FullCalendarModule
            ],
            exports: [EqpCalendarComponent]
        })
    ], EqpCalendarModule);
    return EqpCalendarModule;
}());

var ViewDateChangeEvent = /** @class */ (function () {
    function ViewDateChangeEvent() {
    }
    return ViewDateChangeEvent;
}());

/*
 * Public API Surface of eqp-calendar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EqpCalendarComponent, EqpCalendarModule, EqpCalendarService, ViewDateChangeEvent };
//# sourceMappingURL=eqproject-eqp-calendar.js.map
